<?php

namespace Drupal\pdf_slideshow\Gateway;

use Drupal\Core\File\FileSystem;
use Drupal\Core\State\State;
use Drupal\pdf_slideshow\Manager\PdfSlideshowImagickManager;

class PdfSlideshowStorageGateway {

  /**
   * @var State
   */
  protected $state;

  /**
   * @var FileSystem
   */
  protected $fileSystem;

  protected $pdfSlideshowImagickManager;

  protected $pdfSlideshowEntityGateway;

  /**
   * PdfSlideshowStorageGateway constructor.
   *
   * @param \Drupal\Core\State\State $state
   * @param \Drupal\Core\File\FileSystem $fileSystem
   * @param \Drupal\pdf_slideshow\Manager\PdfSlideshowImagickManager $pdfSlideshowImagickManager
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
   */
  public function __construct(
    State $state,
    FileSystem $fileSystem,
    PdfSlideshowImagickManager $pdfSlideshowImagickManager,
    PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
  ) {
    $this->state = $state;
    $this->fileSystem = $fileSystem;
    $this->pdfSlideshowImagickManager = $pdfSlideshowImagickManager;
    $this->pdfSlideshowEntityGateway = $pdfSlideshowEntityGateway;
  }

  public function fetchPdfImageIds($fid) {
    $values = $this->state->get('pdf_slideshow.' . $fid);
    if ($values) {
      return explode('_', $values);
    }
    return NULL;
  }

  /**
   * Persist images.
   *
   * @param $fileEntity
   *
   * @param $width
   * @param $height
   * @param $limit
   *
   * @return mixed
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \ImagickException
   */
  public function persistPdfImageIds($fileEntity, $width, $height, $limit) {
    if ($fileEntity && $fileEntity->getMimeType() == 'application/pdf') {
      $fileUri = $fileEntity->getFileUri();
      $fileUriArray = explode('/', $fileUri);
      $fileName = end($fileUriArray);
      $sourcePath = $this->fileSystem->realpath($fileUri);
      if ($sourcePath) {
        $imageUrls = $this->pdfSlideshowImagickManager->generateImage($sourcePath,
          $fileName . '.png', $width, $height, $limit);
        $fileEntityIds = $this->pdfSlideshowEntityGateway->createFileEntities($imageUrls);
        $this->state->set('pdf_slideshow.' . $fileEntity->id(),
          implode('_', $fileEntityIds));
        return $this->pdfSlideshowEntityGateway->getPdfFileImageUrls($fileEntityIds);
      }
    }
    return NULL;
  }

}