<?php

namespace Drupal\pdf_slideshow\Manager;

use Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway;
use Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway;

/**
 * Class PdfSlideshowImageManager
 *
 * @package Drupal\pdf_slideshow\Manager
 */
class PdfSlideshowImageManager {

  /**
   * @var \Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway
   */
  protected $pdfSlideshowStorageGateway;

  /**
   * @var \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway
   */
  protected $pdfSlideshowEntityGateway;

  /**
   * PdfSlideshowManager constructor.
   *
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowStorageGateway $pdfSlideshowStorageGateway
   * @param \Drupal\pdf_slideshow\Gateway\PdfSlideshowEntityGateway $pdfSlideshowEntityGateway
   */
  public function __construct(
    PdfSlideshowStorageGateway $pdfSlideshowStorageGateway,
    pdfSlideshowEntityGateway $pdfSlideshowEntityGateway
  ) {
    $this->pdfSlideshowStorageGateway = $pdfSlideshowStorageGateway;
    $this->pdfSlideshowEntityGateway = $pdfSlideshowEntityGateway;
  }

  /**
   * Get pdf image url.
   *
   * @param array $fileEntities
   * @param $width
   * @param $height
   * @param $limit
   *
   * @return array|null
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \ImagickException
   */
  public function getPdfImageUrls(
    $fileEntities,
    $width,
    $height,
    $limit
  ) {
    $output = [];
    foreach ($fileEntities as $fileEntity) {
      $pdfImagesId = $this->pdfSlideshowStorageGateway->fetchPdfImageIds($fileEntity->id());
      if ($pdfImagesId) {
        $urls = $this->pdfSlideshowEntityGateway->getPdfFileImageUrls($pdfImagesId);
        if (count($urls) != intval($limit)) {
          $urls = $this->pdfSlideshowStorageGateway->persistPdfImageIds($fileEntity,
            $width, $height,
            $limit);
        }
      }
      else {
        $urls = $this->pdfSlideshowStorageGateway->persistPdfImageIds($fileEntity,
          $width, $height,
          $limit);
      }
      $output[] = $urls;
    }
    return $output;
  }

}